Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2018-12-23 23:58:59 +0300
committerBastien Montagne <montagne29@wanadoo.fr>2018-12-24 00:03:43 +0300
commit1158b9f73a3d9903657a95736897f570c2cb46ad (patch)
tree10bd8fb725f76989e82113517212febbce7fbc72 /source
parent064cbe9f3fe07e65b3f74ef7fd034e0e62934ace (diff)
Cleanup: First batch of UI messages fixes (typos, final points...).
Also contains some code typo fixes (mostly, adtaptative -> adaptive, former is nearly innexistant in English, let's stick to simple valid words ;) ).
Diffstat (limited to 'source')
-rw-r--r--source/blender/blenfont/intern/blf_glyph.c4
-rw-r--r--source/blender/blenkernel/intern/gpencil_modifier.c2
-rw-r--r--source/blender/blenloader/intern/blend_validate.c14
-rw-r--r--source/blender/blenloader/intern/writefile.c2
-rw-r--r--source/blender/draw/engines/eevee/eevee_lightcache.c4
-rw-r--r--source/blender/draw/engines/gpencil/gpencil_draw_utils.c2
-rw-r--r--source/blender/editors/gpencil/gpencil_edit.c3
-rw-r--r--source/blender/editors/interface/interface_eyedropper_colorband.c2
-rw-r--r--source/blender/editors/screen/screen_user_menu.c4
-rw-r--r--source/blender/makesdna/DNA_gpencil_modifier_types.h2
-rw-r--r--source/blender/makesdna/DNA_gpencil_types.h4
-rw-r--r--source/blender/makesrna/intern/rna_gpencil.c8
-rw-r--r--source/blender/makesrna/intern/rna_gpencil_modifier.c6
-rw-r--r--source/blender/makesrna/intern/rna_modifier.c3
-rw-r--r--source/blender/makesrna/intern/rna_scene.c2
-rw-r--r--source/blender/makesrna/intern/rna_shader_fx.c8
-rw-r--r--source/blender/windowmanager/intern/wm_files.c2
17 files changed, 37 insertions, 35 deletions
diff --git a/source/blender/blenfont/intern/blf_glyph.c b/source/blender/blenfont/intern/blf_glyph.c
index 2679deea254..8fcba1fc2af 100644
--- a/source/blender/blenfont/intern/blf_glyph.c
+++ b/source/blender/blenfont/intern/blf_glyph.c
@@ -413,7 +413,7 @@ static void blf_texture5_draw(const unsigned char color_in[4], int tex_w, int te
float ofs[2] = { 2 / (float)tex_w, 2 / (float)tex_h };
float uv_flag[2][2];
copy_v4_v4((float *)uv_flag, (float *)uv);
- /* flag the x and y component signs for 5x5 bluring */
+ /* flag the x and y component signs for 5x5 blurring */
uv_flag[0][0] = -(uv_flag[0][0] - ofs[0]);
uv_flag[0][1] = -(uv_flag[0][1] - ofs[1]);
uv_flag[1][0] = -(uv_flag[1][0] + ofs[0]);
@@ -428,7 +428,7 @@ static void blf_texture3_draw(const unsigned char color_in[4], int tex_w, int te
float ofs[2] = { 1 / (float)tex_w, 1 / (float)tex_h };
float uv_flag[2][2];
copy_v4_v4((float *)uv_flag, (float *)uv);
- /* flag the x component sign for 3x3 bluring */
+ /* flag the x component sign for 3x3 blurring */
uv_flag[0][0] = -(uv_flag[0][0] - ofs[0]);
uv_flag[0][1] = (uv_flag[0][1] - ofs[1]);
uv_flag[1][0] = -(uv_flag[1][0] + ofs[0]);
diff --git a/source/blender/blenkernel/intern/gpencil_modifier.c b/source/blender/blenkernel/intern/gpencil_modifier.c
index 68691cd3d05..534166bf629 100644
--- a/source/blender/blenkernel/intern/gpencil_modifier.c
+++ b/source/blender/blenkernel/intern/gpencil_modifier.c
@@ -275,7 +275,7 @@ void BKE_gpencil_simplify_stroke(bGPDstroke *gps, float factor)
MEM_SAFE_FREE(points2d);
}
-/* Simplify alternate vertex of stroke except extrems */
+/* Simplify alternate vertex of stroke except extremes */
void BKE_gpencil_simplify_fixed(bGPDstroke *gps)
{
if (gps->totpoints < 5) {
diff --git a/source/blender/blenloader/intern/blend_validate.c b/source/blender/blenloader/intern/blend_validate.c
index 1bc503719b4..07d0379553d 100644
--- a/source/blender/blenloader/intern/blend_validate.c
+++ b/source/blender/blenloader/intern/blend_validate.c
@@ -68,7 +68,7 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
if (id->lib != NULL) {
is_valid = false;
BKE_reportf(reports, RPT_ERROR,
- "ID %s is in local database while being linked from library %s!\n", id->name, id->lib->name);
+ "ID %s is in local database while being linked from library %s!", id->name, id->lib->name);
}
}
}
@@ -77,7 +77,7 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
Library *curlib = curmain->curlib;
if (curlib == NULL) {
BKE_reportf(reports, RPT_ERROR,
- "Library database with NULL library datablock!\n");
+ "Library database with NULL library datablock!");
continue;
}
@@ -86,7 +86,7 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
if (bh == NULL) {
BKE_reportf(reports, RPT_ERROR,
- "Library ID %s not found at expected path %s!\n", curlib->id.name, curlib->filepath);
+ "Library ID %s not found at expected path %s!", curlib->id.name, curlib->filepath);
continue;
}
@@ -100,7 +100,7 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
if (GS(id->name) == ID_LI) {
is_valid = false;
BKE_reportf(reports, RPT_ERROR,
- "Library ID %s in library %s, this should not happen!\n", id->name, curlib->name);
+ "Library ID %s in library %s, this should not happen!", id->name, curlib->name);
continue;
}
@@ -110,13 +110,13 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
if (id->lib == NULL) {
is_valid = false;
BKE_reportf(reports, RPT_ERROR,
- "ID %s has NULL lib pointer while being in library %s!\n", id->name, curlib->name);
+ "ID %s has NULL lib pointer while being in library %s!", id->name, curlib->name);
continue;
}
if (id->lib != curlib) {
is_valid = false;
BKE_reportf(reports, RPT_ERROR,
- "ID %s has mismatched lib pointer!\n", id->name);
+ "ID %s has mismatched lib pointer!", id->name);
continue;
}
@@ -131,7 +131,7 @@ bool BLO_main_validate_libraries(struct Main *bmain, struct ReportList *reports)
if (name == NULL) {
is_valid = false;
BKE_reportf(reports, RPT_ERROR,
- "ID %s not found in library %s anymore!\n", id->name, id->lib->name);
+ "ID %s not found in library %s anymore!", id->name, id->lib->name);
continue;
}
}
diff --git a/source/blender/blenloader/intern/writefile.c b/source/blender/blenloader/intern/writefile.c
index c1d09a836cc..d806a9f9bd8 100644
--- a/source/blender/blenloader/intern/writefile.c
+++ b/source/blender/blenloader/intern/writefile.c
@@ -4128,7 +4128,7 @@ bool BLO_write_file(
const int path_list_flag = (BKE_BPATH_TRAVERSE_SKIP_LIBRARY | BKE_BPATH_TRAVERSE_SKIP_MULTIFILE);
if (G.debug & G_DEBUG_IO && mainvar->lock != NULL) {
- BKE_report(reports, RPT_INFO, "Checking sanity of current .blend file *BEFORE* save to disk.");
+ BKE_report(reports, RPT_INFO, "Checking sanity of current .blend file *BEFORE* save to disk");
BLO_main_validate_libraries(mainvar, reports);
}
diff --git a/source/blender/draw/engines/eevee/eevee_lightcache.c b/source/blender/draw/engines/eevee/eevee_lightcache.c
index 74cac25367c..dd27b53ebc8 100644
--- a/source/blender/draw/engines/eevee/eevee_lightcache.c
+++ b/source/blender/draw/engines/eevee/eevee_lightcache.c
@@ -184,7 +184,7 @@ void EEVEE_lightcache_info_update(SceneEEVEE *eevee)
if (lcache != NULL) {
if (lcache->flag & LIGHTCACHE_BAKING) {
- BLI_strncpy(eevee->light_cache_info, IFACE_("Baking light cache."), sizeof(eevee->light_cache_info));
+ BLI_strncpy(eevee->light_cache_info, IFACE_("Baking light cache"), sizeof(eevee->light_cache_info));
return;
}
@@ -196,7 +196,7 @@ void EEVEE_lightcache_info_update(SceneEEVEE *eevee)
BLI_snprintf(eevee->light_cache_info, sizeof(eevee->light_cache_info), IFACE_("%d Ref. Cubemaps, %d Irr. Samples (%s in memory)"), lcache->cube_len - 1, irr_samples, formatted_mem);
}
else {
- BLI_strncpy(eevee->light_cache_info, IFACE_("No light cache in this scene."), sizeof(eevee->light_cache_info));
+ BLI_strncpy(eevee->light_cache_info, IFACE_("No light cache in this scene"), sizeof(eevee->light_cache_info));
}
}
diff --git a/source/blender/draw/engines/gpencil/gpencil_draw_utils.c b/source/blender/draw/engines/gpencil/gpencil_draw_utils.c
index 8b655854ca1..273a8f216a4 100644
--- a/source/blender/draw/engines/gpencil/gpencil_draw_utils.c
+++ b/source/blender/draw/engines/gpencil/gpencil_draw_utils.c
@@ -1121,7 +1121,7 @@ void DRW_gpencil_triangulate_stroke_fill(Object *ob, bGPDstroke *gps)
float minv[2];
float maxv[2];
/* first needs bounding box data */
- if (gpd->flag & GP_DATA_UV_ADAPTATIVE) {
+ if (gpd->flag & GP_DATA_UV_ADAPTIVE) {
gpencil_calc_2d_bounding_box(points2d, gps->totpoints, minv, maxv);
}
else {
diff --git a/source/blender/editors/gpencil/gpencil_edit.c b/source/blender/editors/gpencil/gpencil_edit.c
index 5cfc35d122a..b61ea617b15 100644
--- a/source/blender/editors/gpencil/gpencil_edit.c
+++ b/source/blender/editors/gpencil/gpencil_edit.c
@@ -2101,7 +2101,8 @@ void GPENCIL_OT_dissolve(wmOperatorType *ot)
ot->flag = OPTYPE_UNDO | OPTYPE_REGISTER;
/* props */
- ot->prop = RNA_def_enum(ot->srna, "type", prop_gpencil_dissolve_types, 0, "Type", "Method used for disolving Stroke points");
+ ot->prop = RNA_def_enum(ot->srna, "type", prop_gpencil_dissolve_types, 0,
+ "Type", "Method used for dissolving Stroke points");
}
/* ****************** Snapping - Strokes <-> Cursor ************************ */
diff --git a/source/blender/editors/interface/interface_eyedropper_colorband.c b/source/blender/editors/interface/interface_eyedropper_colorband.c
index f414d524cd8..a807a16671c 100644
--- a/source/blender/editors/interface/interface_eyedropper_colorband.c
+++ b/source/blender/editors/interface/interface_eyedropper_colorband.c
@@ -321,7 +321,7 @@ void UI_OT_eyedropper_colorband_point(wmOperatorType *ot)
/* identifiers */
ot->name = "Eyedropper colorband (points)";
ot->idname = "UI_OT_eyedropper_colorband_point";
- ot->description = "Pointsample a color band";
+ ot->description = "Point-sample a color band";
/* api callbacks */
ot->invoke = eyedropper_colorband_invoke;
diff --git a/source/blender/editors/screen/screen_user_menu.c b/source/blender/editors/screen/screen_user_menu.c
index 399cbb1057d..ef8588ca58c 100644
--- a/source/blender/editors/screen/screen_user_menu.c
+++ b/source/blender/editors/screen/screen_user_menu.c
@@ -264,8 +264,8 @@ static void screen_user_menu_draw(const bContext *C, Menu *menu)
MEM_freeN(um_array);
if (is_empty) {
- uiItemL(menu->layout, IFACE_("No menu items found."), ICON_NONE);
- uiItemL(menu->layout, IFACE_("Right click on buttons to add them to this menu."), ICON_NONE);
+ uiItemL(menu->layout, IFACE_("No menu items found"), ICON_NONE);
+ uiItemL(menu->layout, IFACE_("Right click on buttons to add them to this menu"), ICON_NONE);
}
}
diff --git a/source/blender/makesdna/DNA_gpencil_modifier_types.h b/source/blender/makesdna/DNA_gpencil_modifier_types.h
index af680b8fb9d..476bec9a9f8 100644
--- a/source/blender/makesdna/DNA_gpencil_modifier_types.h
+++ b/source/blender/makesdna/DNA_gpencil_modifier_types.h
@@ -425,7 +425,7 @@ typedef enum eSimplifyGpencil_Mode {
/* Keep only one vertex every n vertices */
GP_SIMPLIFY_FIXED = 0,
/* Use RDP algorithm */
- GP_SIMPLIFY_ADAPTATIVE = 1,
+ GP_SIMPLIFY_ADAPTIVE = 1,
} eSimplifyGpencil_Mode;
typedef struct OffsetGpencilModifierData {
diff --git a/source/blender/makesrna/intern/rna_gpencil.c b/source/blender/makesrna/intern/rna_gpencil.c
index fabb2ec7308..6cec826dccb 100644
--- a/source/blender/makesrna/intern/rna_gpencil.c
+++ b/source/blender/makesrna/intern/rna_gpencil.c
@@ -1474,7 +1474,7 @@ static void rna_def_gpencil_data(BlenderRNA *brna)
prop = RNA_def_property(srna, "xray_mode", PROP_ENUM, PROP_NONE);
RNA_def_property_enum_sdna(prop, NULL, "xray_mode");
RNA_def_property_enum_items(prop, rna_enum_gpencil_xraymodes_items);
- RNA_def_property_ui_text(prop, "Xray", "");
+ RNA_def_property_ui_text(prop, "X-Ray", "");
RNA_def_property_update(prop, NC_GPENCIL | ND_DATA, "rna_GPencil_update");
/* Flags */
@@ -1535,9 +1535,9 @@ static void rna_def_gpencil_data(BlenderRNA *brna)
RNA_def_property_ui_text(prop, "Force Fill Update", "Force recalc of fill data after use deformation modifiers (reduce FPS)");
RNA_def_property_update(prop, NC_GPENCIL | ND_DATA, "rna_GPencil_update");
- prop = RNA_def_property(srna, "use_adaptative_uv", PROP_BOOLEAN, PROP_NONE);
- RNA_def_property_boolean_sdna(prop, NULL, "flag", GP_DATA_UV_ADAPTATIVE);
- RNA_def_property_ui_text(prop, "Adaptative UV", "Automatic UVs are calculated depending of the stroke size");
+ prop = RNA_def_property(srna, "use_adaptive_uv", PROP_BOOLEAN, PROP_NONE);
+ RNA_def_property_boolean_sdna(prop, NULL, "flag", GP_DATA_UV_ADAPTIVE);
+ RNA_def_property_ui_text(prop, "Adaptive UV", "Automatic UVs are calculated depending of the stroke size");
RNA_def_property_update(prop, NC_GPENCIL | ND_DATA, "rna_GPencil_update");
prop = RNA_def_property(srna, "use_autolock_layers", PROP_BOOLEAN, PROP_NONE);
diff --git a/source/blender/makesrna/intern/rna_gpencil_modifier.c b/source/blender/makesrna/intern/rna_gpencil_modifier.c
index aa1517a96d8..4edc10dcaf6 100644
--- a/source/blender/makesrna/intern/rna_gpencil_modifier.c
+++ b/source/blender/makesrna/intern/rna_gpencil_modifier.c
@@ -544,9 +544,9 @@ static void rna_def_modifier_gpencilsimplify(BlenderRNA *brna)
static EnumPropertyItem prop_gpencil_simplify_mode_items[] = {
{GP_SIMPLIFY_FIXED, "FIXED", ICON_IPO_CONSTANT, "Fixed",
- "Delete alternative vertices in the stroke, except extrems"},
- {GP_SIMPLIFY_ADAPTATIVE, "ADAPTATIVE", ICON_IPO_EASE_IN_OUT, "Adaptative",
- "Use a RDP algorithm to simplify" },
+ "Delete alternative vertices in the stroke, except extremes"},
+ {GP_SIMPLIFY_ADAPTIVE, "ADAPTIVE", ICON_IPO_EASE_IN_OUT, "Adaptive",
+ "Use a RDP algorithm to simplify" },
{0, NULL, 0, NULL, NULL}
};
diff --git a/source/blender/makesrna/intern/rna_modifier.c b/source/blender/makesrna/intern/rna_modifier.c
index 9714a6e5484..b9777be0768 100644
--- a/source/blender/makesrna/intern/rna_modifier.c
+++ b/source/blender/makesrna/intern/rna_modifier.c
@@ -3157,7 +3157,8 @@ static void rna_def_modifier_bevel(BlenderRNA *brna)
prop = RNA_def_property(srna, "set_wn_strength", PROP_BOOLEAN, PROP_NONE);
RNA_def_property_boolean_sdna(prop, NULL, "flags", MOD_BEVEL_SET_WN_STR);
- RNA_def_property_ui_text(prop, "Face Strength", "Set face strength of beveled faces for use in WN Modifier");
+ RNA_def_property_ui_text(prop, "Face Strength",
+ "Set face strength of beveled faces for use in Weighted Normal modifier");
RNA_def_property_update(prop, 0, "rna_Modifier_update");
}
diff --git a/source/blender/makesrna/intern/rna_scene.c b/source/blender/makesrna/intern/rna_scene.c
index 90aa997d179..d6f6c54d055 100644
--- a/source/blender/makesrna/intern/rna_scene.c
+++ b/source/blender/makesrna/intern/rna_scene.c
@@ -6238,7 +6238,7 @@ static void rna_def_scene_eevee(BlenderRNA *brna)
RNA_def_property_boolean_sdna(prop, NULL, "flag", SCE_EEVEE_OVERSCAN);
RNA_def_property_boolean_default(prop, 0);
RNA_def_property_ui_text(prop, "Overscan", "Internally render past the image border to avoid "
- "screen-space effects disapearing");
+ "screen-space effects disappearing");
RNA_def_property_override_flag(prop, PROPOVERRIDE_OVERRIDABLE_STATIC);
prop = RNA_def_property(srna, "overscan_size", PROP_FLOAT, PROP_PERCENTAGE);
diff --git a/source/blender/makesrna/intern/rna_shader_fx.c b/source/blender/makesrna/intern/rna_shader_fx.c
index 5c6e2addfc2..84ac8d1ad28 100644
--- a/source/blender/makesrna/intern/rna_shader_fx.c
+++ b/source/blender/makesrna/intern/rna_shader_fx.c
@@ -371,7 +371,7 @@ static void rna_def_shader_fx_rim(BlenderRNA *brna)
RNA_def_property_range(prop, 0.0, 1.0);
RNA_def_property_float_sdna(prop, NULL, "mask_rgb");
RNA_def_property_array(prop, 3);
- RNA_def_property_ui_text(prop, "Mask Color", "Color that must be keept");
+ RNA_def_property_ui_text(prop, "Mask Color", "Color that must be kept");
RNA_def_property_update(prop, NC_OBJECT | ND_MODIFIER, "rna_ShaderFx_update");
prop = RNA_def_property(srna, "mode", PROP_ENUM, PROP_NONE);
@@ -383,7 +383,7 @@ static void rna_def_shader_fx_rim(BlenderRNA *brna)
prop = RNA_def_property(srna, "blur", PROP_INT, PROP_PIXEL);
RNA_def_property_int_sdna(prop, NULL, "blur");
RNA_def_property_range(prop, 0, INT_MAX);
- RNA_def_property_ui_text(prop, "Blur", "Number of pixels for bluring rim (set to 0 to disable)");
+ RNA_def_property_ui_text(prop, "Blur", "Number of pixels for blurring rim (set to 0 to disable)");
RNA_def_property_update(prop, NC_OBJECT | ND_MODIFIER, "rna_ShaderFx_update");
prop = RNA_def_property(srna, "samples", PROP_INT, PROP_NONE);
@@ -470,7 +470,7 @@ static void rna_def_shader_fx_shadow(BlenderRNA *brna)
prop = RNA_def_property(srna, "blur", PROP_INT, PROP_PIXEL);
RNA_def_property_int_sdna(prop, NULL, "blur");
RNA_def_property_range(prop, 0, INT_MAX);
- RNA_def_property_ui_text(prop, "Blur", "Number of pixels for bluring shadow (set to 0 to disable)");
+ RNA_def_property_ui_text(prop, "Blur", "Number of pixels for blurring shadow (set to 0 to disable)");
RNA_def_property_update(prop, NC_OBJECT | ND_MODIFIER, "rna_ShaderFx_update");
prop = RNA_def_property(srna, "samples", PROP_INT, PROP_NONE);
@@ -533,7 +533,7 @@ static void rna_def_shader_fx_glow(BlenderRNA *brna)
prop = RNA_def_property(srna, "radius", PROP_INT, PROP_PIXEL);
RNA_def_property_int_sdna(prop, NULL, "blur[0]");
RNA_def_property_range(prop, 0, INT_MAX);
- RNA_def_property_ui_text(prop, "Radius", "Number of pixels for bluring glow (set to 0 to disable)");
+ RNA_def_property_ui_text(prop, "Radius", "Number of pixels for blurring glow (set to 0 to disable)");
RNA_def_property_update(prop, NC_OBJECT | ND_MODIFIER, "rna_ShaderFx_update");
prop = RNA_def_property(srna, "samples", PROP_INT, PROP_NONE);
diff --git a/source/blender/windowmanager/intern/wm_files.c b/source/blender/windowmanager/intern/wm_files.c
index 5c7d9c1be48..ccd71ff15bf 100644
--- a/source/blender/windowmanager/intern/wm_files.c
+++ b/source/blender/windowmanager/intern/wm_files.c
@@ -853,7 +853,7 @@ void wm_homefile_read(
app_template, app_template_system, sizeof(app_template_system)))
{
/* Can safely continue with code below, just warn it's not found. */
- BKE_reportf(reports, RPT_WARNING, "Application Template '%s' not found.", app_template);
+ BKE_reportf(reports, RPT_WARNING, "Application Template '%s' not found", app_template);
}
/* Insert template name into startup file. */
diff --git a/source/blender/makesdna/DNA_gpencil_types.h b/source/blender/makesdna/DNA_gpencil_types.h
index 4ed87a487fc..3357c97a8d6 100644
--- a/source/blender/makesdna/DNA_gpencil_types.h
+++ b/source/blender/makesdna/DNA_gpencil_types.h
@@ -477,8 +477,8 @@ typedef enum eGPdata_Flag {
GP_DATA_STROKE_FORCE_RECALC = (1 << 17),
/* Special mode drawing polygons */
GP_DATA_STROKE_POLYGON = (1 << 18),
- /* Use adaptative UV scales */
- GP_DATA_UV_ADAPTATIVE = (1 << 19),
+ /* Use adaptive UV scales */
+ GP_DATA_UV_ADAPTIVE = (1 << 19),
/* Autolock not active layers */
GP_DATA_AUTOLOCK_LAYERS = (1 << 20),
/* Internal flag for python update */